## $Id: interfaces.py 18046 2025-03-15 23:59:29Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.unidel')

class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    clearance_fee = schema.Float(
        title = _(u'Acceptance Fee (default)'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Bed Booking Fee'),
        default = 0.0,
        required = False,
        )

    maint_fee = schema.Float(
        title = _(u'Rent (fallback)'),
        default = 0.0,
        required = False,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Course Reg. Fee'),
        default = 0.0,
        required = False,
        )

    transcript_fee = schema.Float(
        title = _(u'Transcript Fee'),
        default = 0.0,
        required = False,
        )

    transcript_student_fee = schema.Float(
        title = _(u'Transcript Fee Students Copy'),
        default = 0.0,
        required = False,
        )

    transcript_local_fee = schema.Float(
        title = _(u'Transcript Fee Local Copy'),
        default = 0.0,
        required = False,
        )

    transcript_inter_fee = schema.Float(
        title = _(u'Transcript Fee International Copy'),
        default = 0.0,
        required = False,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = False,
        )

    interswitch_enabled = schema.Bool(
        title = _(u'Interswitch Collegepay integration enabled'),
        default = True,
        )

    interswitch_paydirect_enabled = schema.Bool(
        title = _(u'Interswitch Paydirect integration enabled'),
        default = True,
        )

    etranzact_webconnect_enabled = schema.Bool(
        title = _(u'Etranzact Webconnect integration enabled'),
        default = False,
        )

    etranzact_payoutlet_enabled = schema.Bool(
        title = _(u'Etranzact Payoutlet integration enabled'),
        default = False,
        )


    # Additional fees in custom package add here

    ugftlocal_clearance_fee = schema.Float(
        title = _(u'UG FT Local Acceptance Fee (without Btech Fee)'),
        default = 0.0,
        required = False,
        )

    ugft_clearance_fee = schema.Float(
        title = _(u'UG FT Non-Local Acceptance Fee (without Btech Fee)'),
        default = 0.0,
        required = False,
        )

    med_reg_fee = schema.Float(
        title = _(u'Medical Registration Fee'),
        default = 0.0,
        required = False,
        )

    teaching_practice_fee = schema.Float(
        title = _(u'Teaching Practice Fee'),
        default = 0.0,
        required = False,
        )

    ijmb_exam_fee = schema.Float(
        title = _(u'IJMB Examination Fees'),
        default = 0.0,
        required = False,
        )

    union_fee = schema.Float(
        title = _(u'Student Union Due'),
        default = 0.0,
        required = False,
        )

    siwes_fee = schema.Float(
        title = _(u'SIWES Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order